@@ -1,9 +1,7 @@
-#!/usr/local/bin/python3.8
-
-from __future__ import print_function
+#!/usr/local/bin/python3.10
 
 import dns.resolver
 
-answers = dns.resolver.query('nominum.com', 'MX')
+answers = dns.resolver.resolve('nominum.com', 'MX')
 for rdata in answers:
     print('Host', rdata.exchange, 'has preference', rdata.preference)
