@@ -1,9 +1,7 @@
-#!/usr/local/bin/python3.7
+#!/usr/local/bin/python3.9
 
 # Two ways of querying a specific nameserver.
 
-from __future__ import print_function
-
 import dns.message
 import dns.rdataclass
 import dns.rdatatype
@@ -33,7 +31,7 @@ import dns.resolver
 
 resolver = dns.resolver.Resolver(configure=False)
 resolver.nameservers = ['8.8.8.8']
-answer = resolver.query('amazon.com', 'NS')
+answer = resolver.resolve('amazon.com', 'NS')
 print('The nameservers are:')
 for rr in answer:
     print(rr.target)
