@@ -1,13 +1,11 @@
-#!/usr/local/bin/python3.6
-
-from __future__ import print_function
+#!/usr/local/bin/python3.9
 
 import dns.query
 import dns.resolver
 import dns.zone
 
-soa_answer = dns.resolver.query('dnspython.org', 'SOA')
-master_answer = dns.resolver.query(soa_answer[0].mname, 'A')
+soa_answer = dns.resolver.resolve('dnspython.org', 'SOA')
+master_answer = dns.resolver.resolve(soa_answer[0].mname, 'A')
 
 z = dns.zone.from_xfr(dns.query.xfr(master_answer[0].address, 'dnspython.org'))
 for n in sorted(z.nodes.keys()):
